@@ -165,12 +165,8 @@ summary.POUMM <- function(object, ...,
 #'   Defaults to "MCMC", resulting in a trace and density plot for the selected
 #'   statistics (see argument stat). Currently, only 'MCMC' type is supported.
 #' @param doPlot Logical indicating whether a plot should be printed on the 
-#'   currently active graphics device or whether to return a list of ggplot 
+#'   currently active graphics device or whether only to return a list of plot- 
 #'   objects for further processing. Defaults to TRUE.
-#' @param interactive Logical indicating whether the user should press a key 
-#'   before generating a next plot (when needed to display two or more plots).
-#'   Defaults to TRUE. Meaningless if 
-#'   doPlot = FALSE.
 #' @param stat A character vector with the names of statistics to be plotted.
 #'   These should be names from the stats-list (see argument statFunctions).
 #'   Defaults to c("alpha", "theta", "sigma", "sigmae", "H2tMean", "H2tInf").
@@ -186,24 +182,63 @@ summary.POUMM <- function(object, ...,
 #'   Default value is 
 #'    paste0("(stat %in% c('H2e','H2tMean','H2tInf','H2tMax') |",
 #'           " (value >= HPDLower & value <= HPDUpper))"). 
+#' @param palette A vector of colors (can be character strings) corresponding to the 
+#' different chains (in their order 1 (prior), 2, 3). Defaults to c("#999999", 
+#' "#0072B2", "#CC79A7", "#E69F00", "#D55E00", "#56B4E9", "#009E73", "#F0E442"),
+#' which is a color-blind friendly.
 #' @param ... Not used; included for compatibility with the generic function plot.
 #' 
-#' @return The function returns nothing if doPlot=TRUE; Otherwise, it returns a
-#'  list with a data.table corresponding to the data passed to ggplot and two
-#'  ggplot objects corresponding to an MCMC-trace and a posterior density plot.
+#' @return If doPlot==TRUE, the function returns nothing and produces output on 
+#' the current graphics device as a side-effect. Otherwise, the function returns
+#' a list of plot-objects: traceplot and densplot.
 #'  
 #' @import ggplot2
+#' @importFrom GGally ggpairs print_if_interactive wrap ggally_text
+#' @importFrom stats cor complete.cases
 #' @import methods
 #'  
+#' @examples 
+#' \dontrun{
+#' library(POUMM)
+#' 
+#' set.seed(1)
+#' 
+#' N <- 1000
+#' 
+#' # create a random non-ultrametric tree of N tips
+#' tree <- ape::rtree(N)  
+#' 
+#' # Simulate the evolution of a trait along the tree
+#' z <- rVNodesGivenTreePOUMM(
+#'   tree, g0 = 8, alpha = 1, theta = 4, sigma = 1.2, sigmae = .8)
+#' 
+#' fit <- POUMM(z[1:N], tree, spec = list(nSamplesMCMC = 4e5))
+#' 
+#' # Summarize the results from the fit in a table:
+#' summary(fit)
+#' 
+#' # Create plots for some of the inferred parameters/statistics:
+#' pl <- plot(fit, stat = c("alpha", "theta", "sigma", "sigmae", "H2tMean"), 
+#'            doZoomIn = TRUE, 
+#'            zoomInFilter = paste("!(stat %in% c('alpha', 'sigma', 'sigmae')) |",
+#'                                 "(value >= 0 & value <= 8)"),
+#'            doPlot = FALSE)
+#' 
+#' pl$traceplot
+#' pl$densplot
+#' }
+#' 
 #' @export
 plot.summary.POUMM <- function(
   x, type=c("MCMC"), 
-  doPlot = TRUE, interactive = TRUE,
+  doPlot = TRUE, 
   stat=c("alpha", "theta", "sigma", "sigmae", "g0", "H2tMean"),
   chain=NULL,
   doZoomIn = FALSE,
   zoomInFilter = paste0("(stat %in% c('H2e','H2tMean','H2tInf','H2tMax') |",
-                        " (value >= HPDLower & value <= HPDUpper))"), ...) {
+                        " (value >= HPDLower & value <= HPDUpper))"), 
+  palette = c("#999999", "#0072B2", "#CC79A7", "#E69F00", "#D55E00", "#56B4E9", "#009E73", "#F0E442"), 
+  ...) {
   
   # declare global variables to avoid CRAN CHECK NOTES "no visible binding":
   N <- estML <- samplePriorMCMC <- HPD <- HPD50 <- ESS <- HPDUpperFiltered <- 
@@ -251,27 +286,221 @@ plot.summary.POUMM <- function(
     data[, HPDLowerFiltered:=max(min(value), unique(HPDLower)), 
          list(stat = factor(stat), chain = factor(chain))]
     
+    .availStats <- data[, as.character(unique(stat))]
+    .stat <- .availStats[1]
+    dtm <- data[stat == .stat, list(stat, it, chain, value)]
+    dtm[, (.stat) := value]
+    dtm[, c("stat", "value") := NULL]
+    
+    for(.stat in .availStats[-1]) {
+      dtm2 <- 
+        data[stat == .stat, 
+             eval(parse(text=paste0("list(it, chain, ", .stat, ' = value)')))]
+      dtm <- merge(dtm, dtm2, by=c("it", "chain"), all=TRUE)
+    }
+    
+    names(palette) <- as.character(1:length(palette))
+    
+    my_ggplot <- function(...) ggplot(...) + 
+      scale_color_manual(values = palette) +
+      scale_fill_manual(values = palette)
+    
     if(type == "MCMC") {
-      traceplot <- ggplot(data) + 
+      traceplot <- my_ggplot(data) + 
         geom_line(aes(x=it, y=value, col = chain)) + 
         facet_wrap(~stat, scales = "free")
       
-      densplot <- ggplot(data) + 
-        geom_density(aes(x=value, col = chain)) + 
-        geom_segment(aes(x=HPDLowerFiltered, xend=HPDUpperFiltered, 
-                         y=0, yend=0, col = chain)) +
-        geom_point(aes(x=estML, y=0)) +
-        facet_wrap(~stat, scales = "free")
+      my_dens <- function(data, mapping, ...) {
+        my_ggplot(data = data, mapping=mapping) +
+          geom_density(..., alpha = 0.5) 
+      }
       
+      my_points <- function(data, mapping, ...) {
+        my_ggplot(data = data, mapping = mapping) + 
+          geom_point(..., alpha = 0.5)
+      }
+      
+      # copied and modified from GGally
+      my_cor <- function(data, mapping, alignPercent = 0, method = "pearson", 
+                use = "complete.obs", corAlignPercent = NULL, corMethod = NULL, 
+                corUse = NULL, ...) {
+        
+        # global variable name to avoid check note:
+        labelp <- NULL
+        
+        # copied from GGally
+        is_date <- function (x) {
+          inherits(x, c("POSIXt", "POSIXct", "POSIXlt", "Date"))
+        }
+        
+        # copied from GGally
+        eval_data_col <- function (data, aes_col) {
+          eval(aes_col, data)
+        }
+        
+        # copied from GGally
+        str_c <- function (..., sep = "", collapse = NULL) {
+          paste(..., sep = sep, collapse = collapse)
+        }
+        if (!is.null(corAlignPercent)) {
+          stop("'corAlignPercent' is deprecated.  Please use argument 'alignPercent'")
+        }
+        if (!is.null(corMethod)) {
+          stop("'corMethod' is deprecated.  Please use argument 'method'")
+        }
+        if (!is.null(corUse)) {
+          stop("'corUse' is deprecated.  Please use argument 'use'")
+        }
+        useOptions <- c("all.obs", "complete.obs", "pairwise.complete.obs", 
+                        "everything", "na.or.complete")
+        use <- pmatch(use, useOptions)
+        if (is.na(use)) {
+          warning("correlation 'use' not found.  Using default value of 'all.obs'")
+          use <- useOptions[1]
+        }
+        else {
+          use <- useOptions[use]
+        }
+        cor_fn <- function(x, y) {
+          cor(x, y, method = method, use = use)
+        }
+        xCol <- deparse(mapping$x)
+        yCol <- deparse(mapping$y)
+        
+        if (is.numeric(eval_data_col(data, mapping$colour))) {
+          stop("ggally_cor: mapping color column must be categorical, not numeric")
+        }
+        colorCol <- deparse(mapping$colour)
+        singleColorCol <- ifelse(is.null(colorCol), NULL, paste(colorCol, 
+                                                                collapse = ""))
+        if (use %in% c("complete.obs", "pairwise.complete.obs", "na.or.complete")) {
+          
+          if (length(colorCol) > 0) {
+            if (singleColorCol %in% colnames(data)) {
+              rows <- complete.cases(data[c(xCol, yCol, colorCol)])
+            }
+            else {
+              rows <- complete.cases(data[c(xCol, yCol)])
+            }
+          } else {
+            rows <- complete.cases(data[c(xCol, yCol)])
+          }
+          if (any(!rows)) {
+            total <- sum(!rows)
+            if (total > 1) {
+              warning("Removed ", total, " rows containing missing values")
+            }
+            else if (total == 1) {
+              warning("Removing 1 row that contained a missing value")
+            }
+          }
+          data <- data[rows, ]
+        }
+        xVal <- data[[xCol]]
+        yVal <- data[[yCol]]
+        if (length(names(mapping)) > 0) {
+          for (i in length(names(mapping)):1) {
+            tmp_map_val <- deparse(mapping[names(mapping)[i]][[1]])
+            if (tmp_map_val[length(tmp_map_val)] %in% colnames(data)) 
+              mapping[[names(mapping)[i]]] <- NULL
+            if (length(names(mapping)) < 1) {
+              mapping <- NULL
+              break
+            }
+          }
+        }
+        if (length(colorCol) < 1) {
+          colorCol <- "ggally_NO_EXIST"
+        }
+        if ((singleColorCol != "ggally_NO_EXIST") && (singleColorCol %in% 
+                                                      colnames(data))) {
+          cord <- as.data.frame(
+            as.data.table(data)[, cor_fn(eval(parse(text=(xCol))), eval(parse(text=yCol))), 
+                                  by=eval(colorCol)])
+          
+          colnames(cord)[2] <- "ggally_cor"
+          cord$ggally_cor <- signif(as.numeric(cord$ggally_cor), 
+                                    3)
+          lev <- levels(data[[colorCol]])
+          ord <- rep(-1, nrow(cord))
+          for (i in 1:nrow(cord)) {
+            for (j in seq_along(lev)) {
+              if (identical(as.character(cord[i, colorCol]), 
+                            as.character(lev[j]))) {
+                ord[i] <- j
+              }
+            }
+          }
+          cord <- cord[order(ord[ord >= 0]), ]
+          cord$label <- str_c(cord[[colorCol]], ": ", cord$ggally_cor)
+          xmin <- min(xVal, na.rm = TRUE)
+          xmax <- max(xVal, na.rm = TRUE)
+          xrange <- c(xmin - 0.01 * (xmax - xmin), xmax + 0.01 * 
+                        (xmax - xmin))
+          ymin <- min(yVal, na.rm = TRUE)
+          ymax <- max(yVal, na.rm = TRUE)
+          yrange <- c(ymin - 0.01 * (ymax - ymin), ymax + 0.01 * 
+                        (ymax - ymin))
+          p <- ggally_text(label = str_c("Correlation: ", ""), 
+                           mapping = mapping, xP = 0.5, yP = 0.9, 
+                           xrange = xrange, yrange = yrange, color = "black", 
+                           ...) + theme(legend.position = "none")
+          xPos <- rep(alignPercent, nrow(cord)) * diff(xrange) + 
+            min(xrange, na.rm = TRUE)
+          yPos <- seq(from = 0.9, to = 0.2, length.out = nrow(cord) + 
+                        1)
+          yPos <- yPos * diff(yrange) + min(yrange, na.rm = TRUE)
+          yPos <- yPos[-1]
+          cordf <- data.frame(xPos = xPos, yPos = yPos, labelp = cord$label, 
+                              colorCol = cord[[colorCol]])
+          cordf$labelp <- factor(cordf$labelp, levels = cordf$labelp)
+          p <- p + geom_text(data = cordf, 
+                             aes(x = xPos, y = yPos, label = labelp, 
+                                 color = colorCol), hjust = "left", ...) + 
+            scale_color_manual(values = palette) + 
+            theme(panel.grid = element_blank(), 
+                  panel.grid.major = element_blank(), 
+                  panel.background = element_rect(color="grey"))
+            
+          p
+        } else {
+          xmin <- min(xVal, na.rm = TRUE)
+          xmax <- max(xVal, na.rm = TRUE)
+          xrange <- c(xmin - 0.01 * (xmax - xmin), xmax + 0.01 * 
+                        (xmax - xmin))
+          ymin <- min(yVal, na.rm = TRUE)
+          ymax <- max(yVal, na.rm = TRUE)
+          yrange <- c(ymin - 0.01 * (ymax - ymin), ymax + 0.01 * 
+                        (ymax - ymin))
+          p <- ggally_text(
+            label = paste("Correlation:\n", 
+                          signif(cor_fn(xVal, yVal), 3), 
+                          sep = "", collapse = ""), mapping, xP = 0.5, 
+                          yP = 0.5, xrange = xrange, yrange = yrange, ...) + 
+            theme(legend.position = "none")
+          p
+        }
+      }
+      
+      densplot <- ggpairs(
+        as.data.frame(dtm), 
+        mapping = aes(fill = chain, color = chain), 
+        columns = .availStats, 
+        diag = list(continuous = my_dens),
+        lower = list(continuous = my_points, 
+                     combo = wrap("box_no_facet")),
+        upper = list(continuous = my_cor, 
+                     combo = wrap("box_no_facet")))
+        
       if(doPlot) {
         print(traceplot) 
-        if(interactive) {
-          print("Press Enter to see the next plot")
+        if(interactive()) {
+          print("Press Enter to see a univariate density plot")
           scan("", what = "character", nlines = 1)
         }
         print(densplot) 
       } else {
-        list(data = data, traceplot = traceplot, densplot = densplot)  
+        list(traceplot = traceplot, densplot = densplot)  
       }
     }
   } else {
